==> mingw-w64-qt6-multimedia-6.2.0-3.src.tar.gz: qtmultimedia-everywhere-src-6.2.0/src/multimedia/platform/android/qandroidformatsinfo.cpp <==
/****************************************************************************
**
** Copyright (C) 2021 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "qandroidformatsinfo_p.h"

#include <qcoreapplication.h>

QT_BEGIN_NAMESPACE

QAndroidFormatInfo::QAndroidFormatInfo()
{
    // Audio/Video/Image formats with their decoder/encoder information is documented at
    // https://developer.android.com/guide/topics/media/media-formats
    decoders = {
        { QMediaFormat::AAC, { QMediaFormat::AudioCodec::AAC }, {} },
        { QMediaFormat::MP3, { QMediaFormat::AudioCodec::MP3}, {} },
        { QMediaFormat::Ogg, { QMediaFormat::AudioCodec::Opus, QMediaFormat::AudioCodec::Vorbis },
                             {} },
        { QMediaFormat::FLAC, { QMediaFormat::AudioCodec::FLAC }, {} },
        { QMediaFormat::Mpeg4Audio, { QMediaFormat::AudioCodec::AAC, QMediaFormat::AudioCodec::FLAC,
                                QMediaFormat::AudioCodec::MP3, QMediaFormat::AudioCodec::Vorbis},
                             {} },
        { QMediaFormat::MPEG4, { QMediaFormat::AudioCodec::MP3, QMediaFormat::AudioCodec::AAC,
                                 QMediaFormat::AudioCodec::FLAC, QMediaFormat::AudioCodec::Vorbis },
                               { QMediaFormat::VideoCodec::H264, QMediaFormat::VideoCodec::H265,
                                 QMediaFormat::VideoCodec::AV1 } },
        { QMediaFormat::Matroska, { QMediaFormat::AudioCodec::MP3, QMediaFormat::AudioCodec::Opus,
                                    QMediaFormat::AudioCodec::Vorbis },
                                  { QMediaFormat::VideoCodec::VP8, QMediaFormat::VideoCodec::VP9,
                                    QMediaFormat::VideoCodec::H264, QMediaFormat::VideoCodec::H265,
                                    QMediaFormat::VideoCodec::AV1} },
        { QMediaFormat::WebM, { QMediaFormat::AudioCodec::Opus, QMediaFormat::AudioCodec::Vorbis },
                              { QMediaFormat::VideoCodec::VP8, QMediaFormat::VideoCodec::VP9} }
    };

    // MP3 encoders doesn't seem to be supported by the default Android SDK
    encoders = {
        { QMediaFormat::AAC, { QMediaFormat::AudioCodec::AAC }, {} },
        { QMediaFormat::MP3, {}, {} },
        { QMediaFormat::FLAC, { QMediaFormat::AudioCodec::FLAC }, {} },
        { QMediaFormat::Mpeg4Audio, {QMediaFormat::AudioCodec::AAC, QMediaFormat::AudioCodec::FLAC},
                             {} },
        { QMediaFormat::MPEG4, { QMediaFormat::AudioCodec::AAC, QMediaFormat::AudioCodec::FLAC },
                               { QMediaFormat::VideoCodec::H264 } }
    };

    // Opus encoder available only for Android 10+
    if (QNativeInterface::QAndroidApplication::sdkVersion() >= 29) {
        encoders.append({ QMediaFormat::Ogg, { QMediaFormat::AudioCodec::Opus }, {} });
        encoders.append({ QMediaFormat::Matroska, { QMediaFormat::AudioCodec::MP3,
                                                    QMediaFormat::AudioCodec::Opus },
                          { QMediaFormat::VideoCodec::VP8, QMediaFormat::VideoCodec::H264 } });
        encoders.append({ QMediaFormat::WebM, { QMediaFormat::AudioCodec::Opus },
                          { QMediaFormat::VideoCodec::VP8 } });
    } else {
        encoders.append({ QMediaFormat::Ogg, {}, {} });
        encoders.append({ QMediaFormat::Matroska, { QMediaFormat::AudioCodec::MP3 },
                          { QMediaFormat::VideoCodec::VP8, QMediaFormat::VideoCodec::H264 } });
        encoders.append({ QMediaFormat::WebM, {}, { QMediaFormat::VideoCodec::VP8 } });
    }

    imageFormats << QImageCapture::JPEG << QImageCapture::PNG << QImageCapture::WebP;
}

QAndroidFormatInfo::~QAndroidFormatInfo()
{

}

QT_END_NAMESPACE

==> mingw-w64-qt6-multimedia-6.2.1-1.src.tar.gz: qtmultimedia-everywhere-src-6.2.1/src/multimedia/platform/android/qandroidformatsinfo.cpp <==
/****************************************************************************
**
** Copyright (C) 2021 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "qandroidformatsinfo_p.h"

#include <qcoreapplication.h>

QT_BEGIN_NAMESPACE

QAndroidFormatInfo::QAndroidFormatInfo()
{
    // Audio/Video/Image formats with their decoder/encoder information is documented at
    // https://developer.android.com/guide/topics/media/media-formats
    decoders = {
        { QMediaFormat::AAC, { QMediaFormat::AudioCodec::AAC }, {} },
        { QMediaFormat::MP3, { QMediaFormat::AudioCodec::MP3}, {} },
        { QMediaFormat::Ogg, { QMediaFormat::AudioCodec::Opus, QMediaFormat::AudioCodec::Vorbis },
                             {} },
        { QMediaFormat::FLAC, { QMediaFormat::AudioCodec::FLAC }, {} },
        { QMediaFormat::Mpeg4Audio, { QMediaFormat::AudioCodec::AAC, QMediaFormat::AudioCodec::FLAC,
                                QMediaFormat::AudioCodec::MP3, QMediaFormat::AudioCodec::Vorbis},
                             {} },
        { QMediaFormat::MPEG4, { QMediaFormat::AudioCodec::MP3, QMediaFormat::AudioCodec::AAC,
                                 QMediaFormat::AudioCodec::FLAC, QMediaFormat::AudioCodec::Vorbis },
                               { QMediaFormat::VideoCodec::H264, QMediaFormat::VideoCodec::H265,
                                 QMediaFormat::VideoCodec::AV1 } },
        { QMediaFormat::Matroska, { QMediaFormat::AudioCodec::MP3, QMediaFormat::AudioCodec::Opus,
                                    QMediaFormat::AudioCodec::Vorbis },
                                  { QMediaFormat::VideoCodec::VP8, QMediaFormat::VideoCodec::VP9,
                                    QMediaFormat::VideoCodec::H264, QMediaFormat::VideoCodec::H265,
                                    QMediaFormat::VideoCodec::AV1} },
        { QMediaFormat::WebM, { QMediaFormat::AudioCodec::Opus, QMediaFormat::AudioCodec::Vorbis },
                              { QMediaFormat::VideoCodec::VP8, QMediaFormat::VideoCodec::VP9} }
    };

    // MP3 encoders doesn't seem to be supported by the default Android SDK
    encoders = {
        { QMediaFormat::AAC, { QMediaFormat::AudioCodec::AAC }, {} },
        { QMediaFormat::MP3, {}, {} },
        { QMediaFormat::FLAC, { QMediaFormat::AudioCodec::FLAC }, {} },
        { QMediaFormat::Mpeg4Audio, {QMediaFormat::AudioCodec::AAC, QMediaFormat::AudioCodec::FLAC},
                             {} },
        { QMediaFormat::MPEG4, { QMediaFormat::AudioCodec::AAC, QMediaFormat::AudioCodec::FLAC },
                               { QMediaFormat::VideoCodec::H264 } }
    };

    // Opus encoder available only for Android 10+
    if (QNativeInterface::QAndroidApplication::sdkVersion() >= 29) {
        encoders.append({ QMediaFormat::Ogg, { QMediaFormat::AudioCodec::Opus }, {} });
        encoders.append({ QMediaFormat::Matroska, { QMediaFormat::AudioCodec::MP3,
                                                    QMediaFormat::AudioCodec::Opus },
                          { QMediaFormat::VideoCodec::VP8, QMediaFormat::VideoCodec::H264 } });
        encoders.append({ QMediaFormat::WebM, { QMediaFormat::AudioCodec::Opus },
                          { QMediaFormat::VideoCodec::VP8 } });
    } else {
        encoders.append({ QMediaFormat::Ogg, {}, {} });
        encoders.append({ QMediaFormat::Matroska, { QMediaFormat::AudioCodec::MP3 },
                          { QMediaFormat::VideoCodec::VP8, QMediaFormat::VideoCodec::H264 } });
        encoders.append({ QMediaFormat::WebM, {}, { QMediaFormat::VideoCodec::VP8 } });
    }

    // TODO: Add later if needed
    imageFormats << QImageCapture::JPEG /*<< QImageCapture::PNG << QImageCapture::WebP*/;
}

QAndroidFormatInfo::~QAndroidFormatInfo()
{

}

QT_END_NAMESPACE
